### 0.10.9 {small}`2024-10-01`

```{rubric} Features
```
* add `key_added` parameter to `tl.pca`, `tl.tsne`, and `tl.umap` that allows to control where to put the output within the AnnData object {pr}`244` {smaller}`P Angerer`
* adds `pp.bbknn` using `raft` and `cuml` as the backend {pr}`264` {smaller}`S Dicks`

```{rubric} Misc
```
* refactor docstrings to work better in RTD {pr}`242` {smaller}`S Dicks`
* remove Conda from CI {pr}`247` {smaller}`S Dicks`
* add `cupy` as rapids dependency {pr}`254` {smaller}`S Dicks`
* refactored `pp.neighbors` {pr}`264` {smaller}`S Dicks`
